@@ -134,6 +134,10 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -151,6 +155,9 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -162,6 +169,12 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
   # Example 2, using trivial outcome string
   x <- fit(model_fitter, '')
@@ -225,6 +238,10 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -241,6 +258,9 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -252,6 +272,12 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
   # Example 3, using tibble of outcomes
   outcomes <- tibble(
@@ -322,6 +348,10 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.integer(n_at_recommended_dose(x)))
   expect_equal(length(n_at_recommended_dose(x)), 1)
 
+  expect_equal(is_randomising(x), FALSE)
+  expect_true(is.logical(is_randomising(x)))
+  expect_equal(length(is_randomising(x)), 1)
+
   expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
   expect_true(is.numeric(prob_administer(x)))
   expect_equal(length(prob_administer(x)), num_doses(x))
@@ -339,6 +369,9 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.numeric(median_prob_tox(x)))
   expect_equal(length(median_prob_tox(x)), num_doses(x))
 
+  expect_true(is.logical(dose_admissible(x)))
+  expect_equal(length(dose_admissible(x)), num_doses(x))
+
   expect_true(is.numeric(prob_tox_quantile(x, p = 0.9)))
   expect_equal(length(prob_tox_quantile(x, p = 0.9)), num_doses(x))
 
@@ -350,6 +383,12 @@ test_that('demand_n_at_dose_selector supports correct interface.', {
   expect_true(is.data.frame(prob_tox_samples(x)))
   expect_true(is.data.frame(prob_tox_samples(x, tall = TRUE)))
 
+  # Expect summary to not error. This is how that is tested, apparently:
+  expect_error(summary(x), NA)
+  expect_output(print(x))
+  expect_true(tibble::is_tibble(as_tibble(x)))
+  expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 })
 
 
