@@ -1066,6 +1066,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1082,6 +1086,12 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
     # Example 2, empty outcome string..
     x <- three_plus_three_fitter %>% fit('')
@@ -1144,6 +1154,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -1159,6 +1173,12 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
     # Example 3, using tibble
     outcomes <- tibble::tibble(
@@ -1228,6 +1248,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1244,6 +1268,12 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
   })
 
 
@@ -1316,6 +1346,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1332,6 +1366,12 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
     # Example 2, empty outcome string..
     x <- three_plus_three_fitter %>% fit('')
@@ -1393,6 +1433,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
 
@@ -1408,6 +1452,12 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
 
     # Example 3, using tibble
     outcomes <- tibble::tibble(
@@ -1477,6 +1527,10 @@ test_that(
     expect_true(is.integer(n_at_recommended_dose(x)))
     expect_equal(length(n_at_recommended_dose(x)), 1)
 
+    expect_equal(is_randomising(x), FALSE)
+    expect_true(is.logical(is_randomising(x)))
+    expect_equal(length(is_randomising(x)), 1)
+
     expect_equal(unname(prob_administer(x)), c(0.5,0.5,0,0,0))
     expect_true(is.numeric(prob_administer(x)))
     expect_equal(length(prob_administer(x)), num_doses(x))
@@ -1493,4 +1547,10 @@ test_that(
     expect_error(prob_tox_samples(x))
     expect_error(prob_tox_samples(x, tall = TRUE))
 
+    # Expect summary to not error. This is how that is tested, apparently:
+    expect_error(summary(x), NA)
+    expect_output(print(x))
+    expect_true(tibble::is_tibble(as_tibble(x)))
+    expect_true(nrow(as_tibble(x)) >= num_doses(x))
+
   })
